@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 Filip Wasilewski <filipwasilewski@gmail.com>
+# Copyright (c) 2006-2010 Filip Wasilewski <http://filipwasilewski.pl/>
 # See COPYING for license details.
 
-# $Id: __init__.py 51 2006-09-23 14:06:13Z filipw $
+# $Id: __init__.py 154 2010-03-13 13:18:59Z filipw $
 
 """
 Discrete forward and inverse wavelet transform, stationary wavelet transform,
@@ -11,20 +11,19 @@ wavelet packets signal decomposition and reconstruction module.
 """
 
 from _pywt import *
-from wnames import *
 from multilevel import *
 from multidim import *
-from wavelet_packets import WaveletPacket
-import tresholding
+from wavelet_packets import *
+from functions import *
+import thresholding
 
 from release_details import version as __version__, author as __author__, license as __license__
 __all__ = []
 __all__ += _pywt.__all__
-__all__ += wnames.__all__
 __all__ += wavelet_packets.__all__
 __all__ += multilevel.__all__
 __all__ += multidim.__all__
-__all__ += ['__version__', '__author__']
-          
-#del _pywt
-del wnames, multilevel, multidim, wavelet_packets
+__all__ += functions.__all__
+__all__ += ['thresholding']
+
+del multilevel, multidim, wavelet_packets
